# infinite-relations
A project for my Bachelor thesis on extending relational algebra by adding infinite tables.

Enables you to create and perform basic relational operations on infinite relations represented by Python generators.

Can be installed with pip:

**pip install** infinite-relations

Main functionality is contained in *./infinite_relations* folder.
It is provided in this repository along with tests and examples.
